@@ -16,10 +16,14 @@ module Serverspec
       end
 
       def contain(pattern, from, to)
-        if (from || to).nil?
-          cmd = backend.check_file_contain(@name, pattern)
+        if pattern.is_a?(Array)
+          backend.check_file_contain_lines(@name, pattern, from, to)
         else
-          cmd = backend.check_file_contain_within(@name, pattern, from, to)
+          if (from || to).nil?
+            backend.check_file_contain(@name, pattern)
+          else
+            backend.check_file_contain_within(@name, pattern, from, to)
+          end
         end
       end
 
@@ -67,6 +71,10 @@ module Serverspec
         backend.check_mounted(@name, attr, only_with)
       end
 
+      def match_checksum(checksum)
+        backend.check_file_checksum(@name, checksum)
+      end
+
       def match_md5checksum(md5sum)
         backend.check_file_md5checksum(@name, md5sum)
       end
@@ -77,10 +85,14 @@ module Serverspec
 
       def content
         if @content.nil?
-          @content = backend.run_command(commands.get_file_content(@name))[:stdout]
+          @content = backend.run_command(commands.get_file_content(@name)).stdout
         end
         @content
       end
+
+      def version?(version)
+        backend.check_file_version(@name, version)
+      end
     end
   end
 end
