@@ -8,6 +8,10 @@ module Serverspec
       def reachable?(port, proto, timeout)
         backend.check_reachable(@name, port, proto, timeout)
       end
+
+      def ipaddress
+        backend.get_ipaddress_of_host(@name).stdout.strip
+      end
     end
   end
 end
