@@ -4,7 +4,7 @@ include SpecInfra::Helper::Plamo
 
 describe cron do
   it { should have_entry '* * * * * /usr/local/bin/batch.sh' }
-  its(:command) { should eq 'crontab -l | grep -- \\\\\\*\\ \\\\\\*\\ \\\\\\*\\ \\\\\\*\\ \\\\\\*\\ /usr/local/bin/batch.sh' }
+  its(:command) { should eq 'crontab -l | grep -v "#" -- | grep -- \\\\\\*\\ \\\\\\*\\ \\\\\\*\\ \\\\\\*\\ \\\\\\*\\ /usr/local/bin/batch.sh' }
 end
 
 describe cron do
@@ -13,7 +13,7 @@ end
 
 describe cron do
   it { should have_entry('* * * * * /usr/local/bin/batch.sh').with_user('root') }
-  its(:command) { should eq 'crontab -u root -l | grep -- \\\\\\*\\ \\\\\\*\\ \\\\\\*\\ \\\\\\*\\ \\\\\\*\\ /usr/local/bin/batch.sh' }
+  its(:command) { should eq 'crontab -u root -l | grep -v "#" | grep -- \\\\\\*\\ \\\\\\*\\ \\\\\\*\\ \\\\\\*\\ \\\\\\*\\ /usr/local/bin/batch.sh' }
 end
 
 describe cron do
